@@ -35,8 +35,14 @@ export * from './ReferenceDataRelation';
 export * from './VitalLog';
 export * from './Vitals';
 export * from './Procedure';
+
 export * from './EncounterDiagnosis';
-export * from './EncounterMedication';
+export * from './Prescription';
+export * from './PatientOngoingPrescription';
+export * from './EncounterPrescription';
+export * from './EncounterPausePrescription';
+export * from './EncounterPausePrescriptionHistory';
+
 export * from './EncounterDiet';
 export * from './LabRequest';
 export * from './LabRequestAttachment';
@@ -55,6 +61,7 @@ export * from './Program';
 export * from './ProgramRegistry';
 export * from './ProgramRegistryClinicalStatus';
 export * from './ProgramRegistryCondition';
+export * from './ProgramRegistryConditionCategory';
 export * from './PatientProgramRegistration';
 export * from './PatientProgramRegistrationCondition';
 export * from './Survey';
@@ -104,6 +111,14 @@ export * from './InvoicePayment';
 export * from './InvoicePatientPayment';
 export * from './InvoiceInsurerPayment';
 
+export * from './ReferenceDrug';
+export * from './MedicationAdministrationRecord';
+export * from './MedicationAdministrationRecordDose';
+export * from './ReferenceMedicationTemplate';
+
+export * from './PharmacyOrder';
+export * from './PharmacyOrderPrescription';
+
 export * from './Notification';
 
 export * from './Signer';
